@@ -28,6 +28,9 @@
 /* Define if you have the <mysql.h> header file.  */
 #undef HAVE_MYSQL_H
 
+/* Define if tables must be split using MERGE to unite them.  */
+#undef TABLE_SPLIT
+
 @TOP@
 
 /* Type of second argument of getsockname */
