@@ -70,12 +70,18 @@ int main(int argc, char** argv)
   if(params.keys ||
      params.keys_md5 ||
      params.keys_normalize ||
-     params.keys_url)
-    fix_keys();
-  else if(params.servers)
-    fix_servers();
-  else
+     params.keys_url || 
+     params.servers) {
+    if(params.servers)
+      fix_servers();
+    if(params.keys ||
+       params.keys_md5 ||
+       params.keys_normalize ||
+       params.keys_url)
+      fix_keys();
+  } else {
     checker();
+  }
   finish();
   return 0;
 }
