@@ -19,7 +19,7 @@
 #ifndef _crawl_h
 #define _crawl_h
 
-#include <hash.h>
+#include <khash.h>
 
 #include <webtools.h>
 #include <webbase.h>
