@@ -50,7 +50,7 @@ typedef struct crawl_context {
 #define CRAWL_MAX_TIMEOUTS	5
 #define CRAWL_MAX_REDIRECTIONS	10
 
-#define CRAWL_USER_AGENT "webbase/5.13"
+#define CRAWL_USER_AGENT "webbase/"WEBBASE_VERSION
 
 int mirror_collect(char* contextp, webbase_url_t* base_url, char* url, int flag);
 webbase_url_t* mirror(crawl_context_t* context, char* url);
