@@ -41,7 +41,7 @@
 #include <dmalloc.h>
 #endif /* HAVE_DMALLOC_H */
 
-#include <hash.h>
+#include <khash.h>
 #include <split.h>
 #include <urldirname.h>
 #include <dirsel.h>
@@ -168,7 +168,7 @@ void dirsel_verbose(int level)
 
 static void dirsel_end_1(hash_t* table)
 {
-  hash_free(table);
+  _K(hash_free)(table);
 }
 
 /*
