@@ -100,6 +100,10 @@ int http_header(char* arg, int, char* buffer, int buffer_size, int flag)
 	
       }
     }
+    /*
+     * Stored date is not valid anymore, we will have to guess again.
+     */
+    webbase_url->w_mtime = 0;
     /*
      * Load fields
      */
@@ -121,6 +125,8 @@ int http_header(char* arg, int, char* buffer, int buffer_size, int flag)
 	  webbase_url_content_length_set(webbase_url, atoi(value));
 	} else if(!strcmp(key, "last-modified")) {
 	  webbase_url_mtime_set(webbase_url, value);
+	} else if(!strcmp(key, "date")) {
+	  webbase_url_date_set(webbase_url, value);
 	} else if(!strcmp(key, "set-cookie")) {
 	  cookies_load(cookies, webbase_url->w_url, value);
 	  webbase_url->w_info |= WEBBASE_URL_INFO_COOKIE;
