@@ -186,15 +186,7 @@ webbase_t* webbase_alloc(int argc, char** argv, struct option options[])
     /*
      * Instruct real_connect to read missing parameters from ~/.my.cnf file.
      */
-    {
-      char* home = getenv("HOME");
-      if(home) {
-	char* cnf_file = (char*)smalloc(strlen(home) + 32);
-	sprintf(cnf_file, "%s/.my.cnf", home);
-	mysql_options(&base->mysql, MYSQL_READ_DEFAULT_FILE, cnf_file);
-	free(cnf_file);
-      }
-    }
+    mysql_options(&base->mysql, MYSQL_READ_DEFAULT_FILE, "my");
     
     if(!(mysql_real_connect(&base->mysql,
 			    base->mysql_host[0] != '\0' ? base->mysql_host : (char*)0,
