@@ -19,6 +19,14 @@
 #ifndef _base64_h
 #define _base64_h
 
+#ifdef __cplusplus
+extern "C" {
+#endif
+
 char *base64_encode(char* string);
 
+#ifdef __cplusplus
+}
+#endif
+
 #endif /* base64_h */
