@@ -19,6 +19,14 @@
 #ifndef _file_exists_h
 #define _file_exists_h
 
+#ifdef __cplusplus
+extern "C" {
+#endif
+
 int file_exists(char* filename);
 
+#ifdef __cplusplus
+}
+#endif
+
 #endif /* file_exists_h */
