@@ -25,7 +25,16 @@
 extern "C" {
 #endif
 
-void getopt_dump(struct option options[]);
+/* added this structure to implement --help feature */
+/* by benoit orihuela (benoit.orihuela@IDEALX.com), on 2000/07/12 */
+struct option_help
+{
+  char *name;
+  char *description;
+};
+
+void getopt_dump(struct option_help options_help[]);
+void getopt_help_merge(struct option_help to[], struct option_help from[]);
 void getopt_merge(struct option to[], struct option from[]);
 
 #ifdef __cplusplus
