@@ -19,6 +19,10 @@
 #ifndef _split_h
 #define _split_h
 
+#ifdef __cplusplus
+extern "C" {
+#endif
+
 /*
  * splitted is NOT allocated using malloc.
  * if trim is true, trailing separators are removed before splitting.
@@ -36,4 +40,8 @@ void split(char* string, int string_length, char*** splitted, int* count, char s
  */
 void split_inplace(char* string, int string_length, char*** splitted, int* count, char separator, int trim);
 
+#ifdef __cplusplus
+}
+#endif
+
 #endif /* split_h */
