@@ -30,6 +30,14 @@
 # endif
 #endif
 
+#ifdef __cplusplus
+extern "C" {
+#endif
+
 time_t string2time(char* string);
 
+#ifdef __cplusplus
+}
+#endif
+
 #endif /* string2time_h */
